
/* Generated data (by glib-mkenums) */

#include "gc.h"

/* enumerations from "./gc.h" */
GType
gc_category_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { GC_CATEGORY_NONE, "GC_CATEGORY_NONE", "none" },
            { GC_CATEGORY_PUNCTUATION, "GC_CATEGORY_PUNCTUATION", "punctuation" },
            { GC_CATEGORY_ARROW, "GC_CATEGORY_ARROW", "arrow" },
            { GC_CATEGORY_BULLET, "GC_CATEGORY_BULLET", "bullet" },
            { GC_CATEGORY_PICTURE, "GC_CATEGORY_PICTURE", "picture" },
            { GC_CATEGORY_CURRENCY, "GC_CATEGORY_CURRENCY", "currency" },
            { GC_CATEGORY_MATH, "GC_CATEGORY_MATH", "math" },
            { GC_CATEGORY_LATIN, "GC_CATEGORY_LATIN", "latin" },
            { GC_CATEGORY_EMOTICON, "GC_CATEGORY_EMOTICON", "emoticon" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("GcCategory"), values);
    }
    return etype;
}

GType
gc_search_error_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { GC_SEARCH_ERROR_FAILED, "GC_SEARCH_ERROR_FAILED", "failed" },
            { GC_SEARCH_ERROR_INVALID_STATE, "GC_SEARCH_ERROR_INVALID_STATE", "invalid-state" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("GcSearchError"), values);
    }
    return etype;
}

GType
gc_search_flag_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GFlagsValue values[] = {
            { GC_SEARCH_FLAG_NONE, "GC_SEARCH_FLAG_NONE", "none" },
            { GC_SEARCH_FLAG_WORD, "GC_SEARCH_FLAG_WORD", "word" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static (g_intern_static_string ("GcSearchFlag"), values);
    }
    return etype;
}



/* Generated data ends here */

